referrerpolicy=no-referrer-when-downgrade

set_keys

Function set_keys 

pub fn set_keys<T: Config>(keys: T::Keys, proof: Vec<u8>)
Sets the session key(s) of the function caller to keys.

Allows an account to set its session key prior to becoming a validator. This doesn’t take effect until the next session.

  • origin: The dispatch origin of this function must be signed.
  • keys: The new session keys to set. These are the public keys of all sessions keys setup in the runtime.
  • proof: The proof that origin has access to the private keys of keys. See impl_opaque_keys for more information about the proof format.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_keys.