pub fn set_keys<T: Config>(keys: T::Keys, proof: Vec<u8>)Expand description
Sets the session key(s) of the function caller to keys.
Allows an account to set its session key prior to becoming a validator. This doesn’t take effect until the next session.
origin: The dispatch origin of this function must be signed.keys: The new session keys to set. These are the public keys of all sessions keys setup in the runtime.proof: The proof thatoriginhas access to the private keys ofkeys. Seeimpl_opaque_keysfor more information about the proof format.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_keys.